@@ -41,7 +41,7 @@ VCardImportExportPluginInterface::~VCardImportExportPluginInterface() = default;
 void VCardImportExportPluginInterface::createAction(KActionCollection *ac)
 {
     QAction *action = ac->addAction(QStringLiteral("file_import_vcard"));
-    action->setText(i18n("Import vCard..."));
+    action->setText(i18n("Import vCard…"));
     action->setWhatsThis(i18n("Import contacts from a vCard file."));
     connect(action, &QAction::triggered, this, &VCardImportExportPluginInterface::slotImportVCard);
     setImportActions(QList<QAction *>() << action);
@@ -50,18 +50,18 @@ void VCardImportExportPluginInterface::createAction(KActionCollection *ac)
 
     action = ac->addAction(QStringLiteral("file_export_vcard40"));
     action->setWhatsThis(i18n("Export contacts to a vCard 4.0 file."));
-    action->setText(i18n("Export vCard 4.0..."));
+    action->setText(i18n("Export vCard 4.0…"));
     connect(action, &QAction::triggered, this, &VCardImportExportPluginInterface::slotExportVCard4);
     exportActionList << action;
 
     action = ac->addAction(QStringLiteral("file_export_vcard30"));
-    action->setText(i18n("Export vCard 3.0..."));
+    action->setText(i18n("Export vCard 3.0…"));
     action->setWhatsThis(i18n("Export contacts to a vCard 3.0 file."));
     connect(action, &QAction::triggered, this, &VCardImportExportPluginInterface::slotExportVCard3);
     exportActionList << action;
 
     action = ac->addAction(QStringLiteral("file_export_vcard21"));
-    action->setText(i18n("Export vCard 2.1..."));
+    action->setText(i18n("Export vCard 2.1…"));
     action->setWhatsThis(i18n("Export contacts to a vCard 2.1 file."));
     connect(action, &QAction::triggered, this, &VCardImportExportPluginInterface::slotExportVCard2);
     exportActionList << action;
