@@ -20,7 +20,7 @@ using namespace KABGravatar;
 GravatarUpdateWidget::GravatarUpdateWidget(QWidget *parent)
     : QWidget(parent)
     , mEmailLab(new QLabel(this))
-    , mSearchGravatar(new QPushButton(i18n("Search"), this))
+    , mSearchGravatar(new QPushButton(i18nc("@action:button", "Search"), this))
     , mResultGravatar(new QLabel(this))
 {
     auto mainLayout = new QGridLayout(this);
@@ -28,7 +28,7 @@ GravatarUpdateWidget::GravatarUpdateWidget(QWidget *parent)
 
     auto hboxEmail = new QHBoxLayout;
 
-    auto lab = new QLabel(i18n("Email:"), this);
+    auto lab = new QLabel(i18nc("@label:textbox", "Email:"), this);
     lab->setObjectName(QLatin1StringView("emaillabel"));
     hboxEmail->addWidget(lab);
 
@@ -68,7 +68,7 @@ void GravatarUpdateWidget::setOriginalUrl(const QUrl &url)
     QImage image;
     QByteArray imageData;
     KIO::TransferJob *job = KIO::get(url, KIO::NoReload);
-    QObject::connect(job, &KIO::TransferJob::data, [&imageData](KIO::Job *, const QByteArray &data) {
+    QObject::connect(job, &KIO::TransferJob::data, this, [&imageData](KIO::Job *, const QByteArray &data) {
         imageData.append(data);
     });
     if (job->exec()) {
