@@ -40,9 +40,9 @@ void MergeContactsDialogTest::shouldHaveDefaultValue()
     for (int i = 0; i < stackedWidget->count(); ++i) {
         QWidget *w = stackedWidget->widget(i);
         const QString objName = w->objectName();
-        const bool hasGoodNamePage = (objName == QLatin1String("notenoughcontactselected") || objName == QLatin1String("nocontactselected")
-                                      || objName == QLatin1String("manualmergeresultwidget") || objName == QLatin1String("selectioninformation")
-                                      || objName == QLatin1String("mergecontactinfowidget"));
+        const bool hasGoodNamePage = (objName == QLatin1StringView("notenoughcontactselected") || objName == QLatin1StringView("nocontactselected")
+                                      || objName == QLatin1StringView("manualmergeresultwidget") || objName == QLatin1StringView("selectioninformation")
+                                      || objName == QLatin1StringView("mergecontactinfowidget"));
         QVERIFY(hasGoodNamePage);
     }
 }
