@@ -16,8 +16,8 @@
 #include <QTest>
 #include <qtestmouse.h>
 
-#include <widgets/mergecontactinfowidget.h>
-#include <widgets/mergecontactloseinformationwarning.h>
+#include "widgets/mergecontactinfowidget.h"
+#include "widgets/mergecontactloseinformationwarning.h"
 using namespace KABMergeContacts;
 
 namespace KABMergeContacts
@@ -79,7 +79,7 @@ void MergeContactWidgetTest::shouldHaveDefaultValueOnCreation()
     for (int i = 0; i < splitter->count(); ++i) {
         const QString objName = splitter->widget(i)->objectName();
 
-        const bool hasName = (objName == QLatin1String("selectcontactwidget")) || (objName == QLatin1String("mergecontactinfowidget"));
+        const bool hasName = (objName == QLatin1StringView("selectcontactwidget")) || (objName == QLatin1StringView("mergecontactinfowidget"));
         QVERIFY(hasName);
     }
 }
