@@ -16,8 +16,8 @@ public:
     ~ConfirmBeforeDeletingDialog() override;
 
 private:
-    void slotSave();
-    void writeConfig();
-    void readConfig();
+    KMAILCONFIRMBEFOREDELETING_NO_EXPORT void slotSave();
+    KMAILCONFIRMBEFOREDELETING_NO_EXPORT void writeConfig();
+    KMAILCONFIRMBEFOREDELETING_NO_EXPORT void readConfig();
     ConfirmBeforeDeletingWidget *const mConfirmBeforeDeletingWidget;
 };
