@@ -29,7 +29,7 @@ QList<QAction *> ConfirmBeforeDeletingInterface::actions() const
 void ConfirmBeforeDeletingInterface::createActions(KActionCollection *ac)
 {
     if (ac) {
-        auto mainMenu = new QAction(i18n("Confirm Before Deleting"), this);
+        auto mainMenu = new QAction(i18nc("@action", "Confirm Before Deleting"), this);
         auto menu = new QMenu;
         auto act = new QAction(QIcon::fromTheme(QStringLiteral("settings-configure")), i18n("Configure"), menu);
         connect(act, &QAction::triggered, this, &ConfirmBeforeDeletingInterface::slotConfigure);
@@ -64,7 +64,7 @@ Akonadi::Item::List ConfirmBeforeDeletingInterface::exec(const Akonadi::Item::Li
 
             QPointer<ConfirmBeforeDeletingMessageBoxDialog> dlg = new ConfirmBeforeDeletingMessageBoxDialog(parentWidget());
             if (checkFoundStr.length() > 200) {
-                checkFoundStr = checkFoundStr.left(200) + QStringLiteral("...");
+                checkFoundStr = checkFoundStr.left(200) + QStringLiteral("…");
             }
             dlg->setInfo(i18n("Do you want to delete this email?\n%1", checkFoundStr));
             const int result = dlg->exec();
