@@ -16,7 +16,7 @@ MarkdownCreateImageWidget::MarkdownCreateImageWidget(QWidget *parent)
     , mTitle(new QLineEdit(this))
     , mImageUrl(new QLineEdit(this))
     , mAlternateText(new QLineEdit(this))
-    , mKeepOriginalSize(new QCheckBox(i18n("Keep original size"), this))
+    , mKeepOriginalSize(new QCheckBox(i18nc("@option:check", "Keep original size"), this))
     , mLabWidth(new QLabel(i18nc("@label:textbox", "Width:"), this))
     , mWidth(new QSpinBox(this))
     , mLabHeight(new QLabel(i18nc("@label:textbox", "Height:"), this))
@@ -43,11 +43,7 @@ MarkdownCreateImageWidget::MarkdownCreateImageWidget(QWidget *parent)
     mKeepOriginalSize->setObjectName(QLatin1StringView("keeporiginalsize"));
     mKeepOriginalSize->setChecked(true);
     mainLayout->addRow(mKeepOriginalSize);
-#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
-    connect(mKeepOriginalSize, &QCheckBox::stateChanged, this, &MarkdownCreateImageWidget::slotKeepOriginalSizeChanged);
-#else
     connect(mKeepOriginalSize, &QCheckBox::checkStateChanged, this, &MarkdownCreateImageWidget::slotKeepOriginalSizeChanged);
-#endif
 
     auto sizeWidget = new QWidget;
     sizeWidget->setObjectName(QLatin1StringView("sizeWidget"));
