@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2024 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,6 +17,6 @@ public:
     explicit TriopAbShortUrlEnginePlugin(QObject *parent = nullptr, const QList<QVariant> & = QList<QVariant>());
     ~TriopAbShortUrlEnginePlugin() override;
 
-    ShortUrlEngineInterface *createInterface(QObject *parent) override;
-    QString engineName() const override;
+    [[nodiscard]] ShortUrlEngineInterface *createInterface(QObject *parent) override;
+    [[nodiscard]] QString engineName() const override;
 };
