@@ -18,7 +18,7 @@ public:
     explicit ZoomTextPluginEditor(QObject *parent = nullptr, const QList<QVariant> & = QList<QVariant>());
     ~ZoomTextPluginEditor() override;
 
-    MessageComposer::PluginEditorInterface *createInterface(QObject *parent = nullptr) override;
+    [[nodiscard]] MessageComposer::PluginEditorInterface *createInterface(QObject *parent = nullptr) override;
     [[nodiscard]] bool hasPopupMenuSupport() const override;
     [[nodiscard]] bool hasStatusBarSupport() const override;
 Q_SIGNALS:
