@@ -19,7 +19,7 @@ AntiVirusPluginInterface::~AntiVirusPluginInterface() = default;
 
 void AntiVirusPluginInterface::createAction(KActionCollection *ac)
 {
-    auto action = new QAction(i18n("&Anti-Virus Wizard..."), this);
+    auto action = new QAction(i18nc("@action", "&Anti-Virus Wizard…"), this);
     ac->addAction(QStringLiteral("antiVirusWizard"), action);
     connect(action, &QAction::triggered, this, &AntiVirusPluginInterface::slotActivated);
     PimCommon::ActionType type(action, PimCommon::ActionType::Tools);
