@@ -17,7 +17,7 @@ public:
     ~FolderSettingFilterProxyModel() override;
 
     [[nodiscard]] QVariant data(const QModelIndex &index, int role) const override;
-    bool setData(const QModelIndex &index, const QVariant &value, int role) override;
+    [[nodiscard]] bool setData(const QModelIndex &index, const QVariant &value, int role) override;
 
     [[nodiscard]] Qt::ItemFlags flags(const QModelIndex &index) const override;
 
