@@ -46,7 +46,7 @@ ViewerPluginInterface::SpecificFeatureTypes ViewerPluginTranslatorInterface::fea
 void ViewerPluginTranslatorInterface::createAction(KActionCollection *ac)
 {
     if (ac) {
-        auto act = new QAction(i18n("Translate..."), this);
+        auto act = new QAction(i18nc("@action", "Translate…"), this);
         ac->setDefaultShortcut(act, QKeySequence(Qt::CTRL | Qt::ALT | Qt::Key_T));
         act->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-locale")));
         ac->addAction(QStringLiteral("translate_text"), act);
