@@ -10,7 +10,6 @@
 #include <Akonadi/ItemFetchJob>
 #include <Akonadi/ItemFetchScope>
 #include <Akonadi/MessageParts>
-#include <Akonadi/RelationCreateJob>
 
 #include <KMime/Message>
 
@@ -72,19 +71,6 @@ void CreateEventJob::slotEventCreated(KJob *job)
         qCDebug(CREATEEVENTPLUGIN_LOG) << "Error during create new Event " << job->errorString();
         setError(job->error());
         setErrorText(job->errorText());
-        emitResult();
-    } else {
-        auto createJob = static_cast<Akonadi::ItemCreateJob *>(job);
-        Akonadi::Relation relation(Akonadi::Relation::GENERIC, mItem, createJob->item());
-        auto rJob = new Akonadi::RelationCreateJob(relation);
-        connect(rJob, &Akonadi::RelationCreateJob::result, this, &CreateEventJob::slotRelationCreated);
-    }
-}
-
-void CreateEventJob::slotRelationCreated(KJob *job)
-{
-    if (job->error()) {
-        qCDebug(CREATEEVENTPLUGIN_LOG) << "Error during create new Event " << job->errorString();
     }
     emitResult();
 }
