@@ -42,7 +42,7 @@ EventEdit::EventEdit(QWidget *parent)
     , mStartDateTimeEdit(new EventDateTimeWidget(this))
     , mEndDateTimeEdit(new EventDateTimeWidget(this))
     , mSaveButton(new QPushButton(QIcon::fromTheme(QStringLiteral("appointment-new")), i18n("&Save"), this))
-    , mOpenEditorButton(new QPushButton(i18n("Open &Editor..."), this))
+    , mOpenEditorButton(new QPushButton(i18nc("@action:button", "Open &Editor…"), this))
 {
     auto vbox = new QVBoxLayout(this);
     vbox->setContentsMargins(5, 5, 5, 5);
@@ -53,7 +53,7 @@ EventEdit::EventEdit(QWidget *parent)
     hbox->setSpacing(2);
     vbox->addLayout(hbox);
 
-    auto lab = new QLabel(i18n("Event:"), this);
+    auto lab = new QLabel(i18nc("@label:textbox", "Event:"), this);
     hbox->addWidget(lab);
 
     mEventEdit->setClearButtonEnabled(true);
@@ -73,7 +73,7 @@ EventEdit::EventEdit(QWidget *parent)
 #ifndef QT_NO_ACCESSIBILITY
     mCollectionCombobox->setAccessibleDescription(i18n("Calendar where the new event will be stored."));
 #endif
-    mCollectionCombobox->setToolTip(i18n("Calendar where the new event will be stored"));
+    mCollectionCombobox->setToolTip(i18nc("@info:tooltip", "Calendar where the new event will be stored"));
 
     connect(mCollectionCombobox, &Akonadi::CollectionComboBox::currentIndexChanged, this, &EventEdit::slotCollectionChanged);
     connect(mCollectionCombobox, &Akonadi::CollectionComboBox::activated, this, &EventEdit::slotCollectionChanged);
@@ -86,7 +86,7 @@ EventEdit::EventEdit(QWidget *parent)
     hbox->setSpacing(2);
     vbox->addLayout(hbox);
 
-    lab = new QLabel(i18n("Start:"), this);
+    lab = new QLabel(i18nc("@label:textbox", "Start:"), this);
     hbox->addWidget(lab);
     QDateTime currentDateTime = QDateTime::currentDateTime();
     mStartDateTimeEdit->setObjectName(QLatin1StringView("startdatetimeedit"));
@@ -99,7 +99,7 @@ EventEdit::EventEdit(QWidget *parent)
 
     hbox->addSpacing(5);
 
-    lab = new QLabel(i18n("End:"), this);
+    lab = new QLabel(i18nc("@label:textbox", "End:"), this);
     hbox->addWidget(lab);
     mEndDateTimeEdit->setObjectName(QLatin1StringView("enddatetimeedit"));
     mEndDateTimeEdit->setDateTime(currentDateTime.addSecs(3600));
