@@ -21,18 +21,18 @@ public:
     ~ViewerPluginCreateTodoInterface() override;
 
     void setText(const QString &text) override;
-    QList<QAction *> actions() const override;
+    [[nodiscard]] QList<QAction *> actions() const override;
     void setMessage(const KMime::Message::Ptr &value) override;
     void closePlugin() override;
     void showWidget() override;
     void setMessageItem(const Akonadi::Item &item) override;
-    ViewerPluginInterface::SpecificFeatureTypes featureTypes() const override;
+    [[nodiscard]] ViewerPluginInterface::SpecificFeatureTypes featureTypes() const override;
     void setCurrentCollection(const Akonadi::Collection &col) override;
 
 private:
     void slotCreateTodo(const KCalendarCore::Todo::Ptr &todoPtr, const Akonadi::Collection &collection);
     void createAction(KActionCollection *ac);
-    TodoEdit *widget();
+    [[nodiscard]] TodoEdit *widget();
 
     TodoEdit *mTodoEdit = nullptr;
     QList<QAction *> mAction;
