@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2023-2024 Laurent Montel <montel.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -32,6 +32,11 @@ void AdblockFilter::setName(const QString &newName)
     mName = newName;
 }
 
+bool AdblockFilter::operator==(const AdblockFilter &other) const
+{
+    return mName == other.name() && mUrl == other.url();
+}
+
 QDebug operator<<(QDebug d, const AdblockFilter &t)
 {
     d << " url " << t.url();
