@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2023-2024 Laurent Montel <montel.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,9 +7,12 @@
 #pragma once
 
 #include "adblockplugin_private_export.h"
+#include <KConfigGroup>
 #include <QWidget>
-class AdblockFilterListsView;
+
+class AdblockFilterTreeView;
 class QLineEdit;
+
 class LIBADBLOCKPLUGIN_TESTS_EXPORT AdblockFilterWidget : public QWidget
 {
     Q_OBJECT
@@ -17,7 +20,13 @@ public:
     explicit AdblockFilterWidget(QWidget *parent = nullptr);
     ~AdblockFilterWidget() override;
 
+    void loadSettings();
+    void saveSettings();
+
+Q_SIGNALS:
+    void settingsChanged();
+
 private:
-    AdblockFilterListsView *const mAdblockFilterListView;
+    AdblockFilterTreeView *const mAdblockFilterListView;
     QLineEdit *const mSearchLineEdit;
 };
