@@ -9,7 +9,6 @@
 #include <WebEngineViewer/NetworkPluginUrlInterceptorInterface>
 #include <WebEngineViewer/WebHitTestResult>
 class QWebEngineView;
-class AdblockManager;
 class AdblockInterceptorInterface : public WebEngineViewer::NetworkPluginUrlInterceptorInterface
 {
     Q_OBJECT
@@ -17,10 +16,10 @@ public:
     explicit AdblockInterceptorInterface(QObject *parent = nullptr);
     ~AdblockInterceptorInterface() override;
 
-    bool interceptRequest(QWebEngineUrlRequestInfo &info) override;
-    QList<QAction *> interceptorUrlActions(const WebEngineViewer::WebHitTestResult &result) const override;
+    [[nodiscard]] bool interceptRequest(QWebEngineUrlRequestInfo &info) override;
+    [[nodiscard]] QList<QAction *> interceptorUrlActions(const WebEngineViewer::WebHitTestResult &result) const override;
     void createActions(KActionCollection *ac) override;
-    QWebEngineView *webEngineView() const;
+    [[nodiscard]] QWebEngineView *webEngineView() const;
 
     void setWebEngineView(QWebEngineView *webEngineView);
 
@@ -29,5 +28,4 @@ private:
     QAction *mShowBlockableItems = nullptr;
     QAction *mBlockImage = nullptr;
     QWebEngineView *mWebEngineView = nullptr;
-    AdblockManager *const mAdblockManager;
 };
