@@ -1,11 +1,11 @@
 /*
-   SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2023-2024 Laurent Montel <montel.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "adblocklistsmanager.h"
-
+#include "libadblockplugin_debug.h"
 #include <QDir>
 #include <QStandardPaths>
 
@@ -13,7 +13,9 @@ AdblockListsManager::AdblockListsManager(QObject *parent)
     : QObject{parent}
     , mFilterListsPath(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QStringLiteral("/filterlists/"))
 {
-    QDir().mkdir(mFilterListsPath);
+    if (!QDir().mkpath(mFilterListsPath)) {
+        qCWarning(LIBADBLOCKPLUGIN_PLUGIN_LOG) << "Impossible to create " << mFilterListsPath;
+    }
 }
 
 AdblockListsManager::~AdblockListsManager() = default;
