@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2023-2024 Laurent Montel <montel.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -29,6 +29,7 @@ AdblockPluginUrlInterceptorAddAdblockListWidget::AdblockPluginUrlInterceptorAddA
 
     mainLayout->addRow(i18n("Name:"), mName);
     mainLayout->addRow(i18n("Url:"), mUrl);
+    mName->setFocus();
 }
 
 AdblockPluginUrlInterceptorAddAdblockListWidget::~AdblockPluginUrlInterceptorAddAdblockListWidget() = default;
@@ -49,7 +50,17 @@ void AdblockPluginUrlInterceptorAddAdblockListWidget::setInfo(const AdBlockListI
 
 bool AdblockPluginUrlInterceptorAddAdblockListWidget::AdBlockListInfo::isValid() const
 {
-    return name.trimmed().isEmpty() && url.trimmed().isEmpty();
+    return !name.trimmed().isEmpty() && !url.trimmed().isEmpty();
+}
+
+bool AdblockPluginUrlInterceptorAddAdblockListWidget::AdBlockListInfo::operator==(const AdBlockListInfo &other) const
+{
+    return name == other.name && url == other.url;
+}
+
+bool AdblockPluginUrlInterceptorAddAdblockListWidget::AdBlockListInfo::operator!=(const AdBlockListInfo &other) const
+{
+    return !AdblockPluginUrlInterceptorAddAdblockListWidget::AdBlockListInfo::operator==(other);
 }
 
 QDebug operator<<(QDebug d, const AdblockPluginUrlInterceptorAddAdblockListWidget::AdBlockListInfo &t)
