@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2023-2024 Laurent Montel <montel.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,10 +13,12 @@ class LIBADBLOCKPLUGIN_TESTS_EXPORT AdblockPluginUrlInterceptorAddAdblockListWid
 {
     Q_OBJECT
 public:
-    struct AdBlockListInfo {
+    struct LIBADBLOCKPLUGIN_TESTS_EXPORT AdBlockListInfo {
         QString name;
         QString url;
         [[nodiscard]] bool isValid() const;
+        [[nodiscard]] bool operator==(const AdBlockListInfo &other) const;
+        [[nodiscard]] bool operator!=(const AdBlockListInfo &other) const;
     };
 
     explicit AdblockPluginUrlInterceptorAddAdblockListWidget(QWidget *parent = nullptr);
