@@ -19,7 +19,7 @@ public:
     void setFilterText(const QString &str);
 
 private:
-    void readConfig();
-    void writeConfig();
+    LIBADBLOCKPLUGIN_NO_EXPORT void readConfig();
+    LIBADBLOCKPLUGIN_NO_EXPORT void writeConfig();
     AdblockViewFilterWidget *const mAdblockViewFilterWidget;
 };
