@@ -1,11 +1,11 @@
 /*
-   SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2023-2024 Laurent Montel <montel.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "adblockfilterwidgettest.h"
-#include "adblockfilterlistsview.h"
+#include "adblockfiltertreeview.h"
 #include "adblockfilterwidget.h"
 #include <QLineEdit>
 #include <QTest>
@@ -28,8 +28,9 @@ void AdblockFilterWidgetTest::shouldHaveDefaultValues()
     QVERIFY(mSearchLineEdit);
     QVERIFY(mSearchLineEdit->text().isEmpty());
     QVERIFY(!mSearchLineEdit->placeholderText().isEmpty());
+    QVERIFY(mSearchLineEdit->isClearButtonEnabled());
 
-    auto mAdblockFilterListView = w.findChild<AdblockFilterListsView *>(QStringLiteral("mAdblockFilterListView"));
+    auto mAdblockFilterListView = w.findChild<AdblockFilterTreeView *>(QStringLiteral("mAdblockFilterListView"));
     QVERIFY(mAdblockFilterListView);
 }
 
