@@ -15,7 +15,11 @@ class SelectImapFolderTreeView : public QTreeView
 public:
     explicit SelectImapFolderTreeView(QWidget *parent);
     ~SelectImapFolderTreeView() override;
-    enum LoadingStatus { InProgress = 0, Success, Failed };
+    enum LoadingStatus {
+        InProgress = 0,
+        Success,
+        Failed
+    };
 
     void setStatus(LoadingStatus status);
 
